# mcpx

mcpx is an extension for the [mcp python sdk](https://github.com/modelcontextprotocol/python-sdk) that includes extra functionality.

This package is aimed at client developers.

## Features

- Docker client transport

## Installation

Install mcpx as a python package via pypi:

```bash
uv add mcpx
```

## Contributing

Contributions are welcome! Please open an issue or submit a pull request.

## License

mcpx is licensed under the MIT License.
